import React from "react";
import type { TableClassNames } from "./table";
import type { TableDataRow } from "./table-row";
/**
 * Unique ID for every column in grid
 */
export type TableColumnId = string;
export interface TableDataColumn<DataItem = any> {
    id: TableColumnId;
    /**
     * Contents of the column that will be rendered.
     */
    title: React.ReactNode;
    className?: string;
    style?: React.CSSProperties;
    /**
     * Current state (width) of resized/resizing column (if any)
     */
    size?: string;
    /**
     * Min-size of the column (width), that can be resized to it manually
     * @default 50px
     */
    minSize?: number;
    /**
     * Defines if specific column could be resized by `width`
     * default: true
     */
    resizable?: boolean;
    /**
     * Defines if specific column could be re-ordered within parent table
     * @default: true
     */
    draggable?: boolean;
    /**
     * Defines if specific column could be used in sorting results
     * @default: true
     */
    sortable?: boolean;
    /**
     * Current state of table items in sorting results (if any)
     */
    sortingOrder?: "asc" | "desc";
    /**
     * This `data-getter` called when some column sorted by user action (UI event)
     * Usually this is a good place to update some external state for the table.
     */
    onSorting?: (row: TableDataRow<DataItem>, col: TableDataColumn<DataItem>, evt: React.MouseEvent) => void;
    /**
     * This `data-getter` called when some column is `resizable` and resizing events by user action (UI event)
     * Usually this is a good place to update some external state for the table (e.g. column sizes).
     */
    onResizeStart?: (info: {
        columnId: TableColumnId;
        size: number;
    }, evt: React.MouseEvent) => void;
    onResizing?: (info: {
        columnId: TableColumnId;
        size: number;
        offsetX: number;
        offsetY: number;
    }, evt: MouseEvent) => void;
    onResizeEnd?: (info: {
        columnId: TableColumnId;
        size: number;
        offsetX: number;
        offsetY: number;
    }, evt: MouseEvent) => void;
    onResizeReset?: (info: {
        columnId: TableColumnId;
    }, evt: React.MouseEvent) => void;
    /**
     * This event happens on successful drag & drop columns on each other when re-ordering.
     * Applicable currently only for heading columns (`table.props.columns`)
     */
    onDragAndDrop?: (result: {
        draggable: TableDataColumn<DataItem>;
        droppable: TableDataColumn<DataItem>;
    }) => void;
    /**
     * Callback to be used in rendering contents in every column (aka "data cell")
     */
    renderValue?: (row: TableDataRow<DataItem>, col: TableDataColumn<DataItem>) => React.ReactNode;
    /**
     * Callback to be used in data sorting items in every row and column
     * By default, if this `data-getter` is not provided `renderValue(): ReactNode` would be used instead.
     * NOTE: sorting doesn't work correctly if `renderValue()` returns not a `string` or `number`.
     */
    sortValue?: (row: TableDataRow<DataItem>, col: TableDataColumn<DataItem>) => string | number;
    /**
     * This callback could be used in filtering rows from search.
     * Provide it to the columns definition (heading) when their `renderValue()` returns non-`string` ReactNode.
     */
    searchValue?: (row: TableDataRow<DataItem>, col: TableDataColumn<DataItem>) => string;
}
export interface TableColumnProps extends TableDataColumn {
    parentRow: TableDataRow;
    classes?: TableClassNames;
    elemRef?: React.RefCallback<HTMLDivElement>;
}
export declare const TableColumn: (columnProps: TableColumnProps) => JSX.Element;
export declare function TableColumnDragIconSvg(props: React.PropsWithChildren & {
    className?: string;
}): JSX.Element;
